@@ -35,6 +35,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 #if defined __GNU_LIBRARY__ && HAVE_GETDELIM
 
+#ifndef HAVE_GETLINE
+
 int
 getline (lineptr, n, stream)
      char **lineptr;
@@ -44,9 +46,18 @@ getline (lineptr, n, stream)
   return getdelim (lineptr, n, '\n', stream);
 }
 
+#endif
+
 #else /* ! have getdelim */
-int
-getdelim (lineptr, n, delimiter, stream);
+
+#if defined(__FreeBSD__)
+#include <osreldate.h>
+#if __FreeBSD_version <= 800066
+int getdelim (lineptr, n, delimiter, stream);
+#else
+ssize_t getdelim (lineptr, n, delimiter, stream);
+#endif
+#endif
 
 # include <assert.h>
 
@@ -150,7 +161,14 @@ getline (lineptr, n, stream)
   return getstr (lineptr, n, stream, '\n', 0);
 }
 
+#if defined(__FreeBSD__)
+#include <osreldate.h>
+#if __FreeBSD_version <= 800066
 int
+#else
+ssize_t
+#endif
+#endif
 getdelim (lineptr, n, delimiter, stream)
      char **lineptr;
      size_t *n;
