@@ -1,7 +1,7 @@
 /*
  *  outofmemory.c
  *
- *  Copyright (C) 1998  Staf Wagemakers Belgie/Belgium
+ *  Copyright (C) 1998, 2006  Staf Wagemakers Belgie/Belgium
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,8 @@
  *
  */
 
-#include <ncurses.h>
+#include "outofmemory.h"
+
 void outofmemory() {
 	fprintf(stderr,"Out of memory\n");
 	endwin();
